@@ -1,6 +1,6 @@
-from credo.asker import ask_user_for_secrets, ask_user_for_half_life, ask_for_choice_or_new, ask_for_env
-from credo.errors import CantEncrypt, CantSign, BadCredential, CredoError
-from credo.helper import print_list_of_tuples, make_export_commands
+from credo.helper import print_list_of_tuples, make_export_commands, normalise_half_life
+from credo.asker import ask_user_for_secrets, ask_for_choice_or_new, ask_for_env
+from credo.errors import CantEncrypt, CantSign, BadCredential
 from credo.amazon import IamPair
 from credo import structure
 
@@ -38,10 +38,12 @@ def do_unset(credo, **kwargs):
     for command in make_export_commands(exports):
         print(command)
 
-def do_exports(credo, chosen=None, repository=None, **kwargs):
+def do_exports(credo, chosen=None, repository=None, half_life=None, **kwargs):
     """Just print out the chosen creds"""
+    half_life = normalise_half_life(half_life or getattr(credo, "half_life", None))
+
     if chosen is None:
-        chosen = credo.chosen
+        chosen = credo._chosen = credo.make_chosen(rotate=True, half_life=half_life)
 
     if repository is None:
         repository = credo.chosen.credential_path.repository
@@ -101,8 +103,11 @@ def do_synchronize(credo, **kwargs):
     repo_name, location = credo.find_one_repository(want_new=False)
     structure.repository.synchronize(repo_name, location, credo.crypto)
 
-def do_exec(credo, command, **kwargs):
+def do_exec(credo, command, half_life=None, **kwargs):
     """Exec some command with aws credentials in the environment"""
+    half_life = normalise_half_life(half_life or getattr(credo, "half_life", None))
+    credo._chosen = credo.make_chosen(rotate=True, half_life=half_life)
+
     environment = dict(os.environ)
     for key, val in credo.chosen.shell_exports():
         if val == "CREDO_UNSET":
@@ -113,10 +118,11 @@ def do_exec(credo, command, **kwargs):
     os.execvpe(command[0], command, environment)
     credo.chosen.credential_path.repository.synchronize()
 
-def do_rotate(credo, force=False, **kwargs):
+def do_rotate(credo, force=False, half_life=None, **kwargs):
     """Rotate some keys"""
     log.info("Doing a rotation")
-    credo.make_chosen(rotate=True, invalidate_creds=force).credential_path.repository.synchronize()
+    half_life = normalise_half_life(half_life or getattr(credo, "half_life", None))
+    credo.make_chosen(rotate=True, invalidate_creds=force, half_life=half_life).credential_path.repository.synchronize()
 
 def do_remote(credo, remote=None, version_with=None, **kwargs):
     """Setup remotes for some repository"""
@@ -143,17 +149,7 @@ def do_import(credo, source=False, half_life=None, **kwargs):
             raise CantSign("No private keys with matching public keys to sign with", repo=cred_path.repository.name)
 
     access_key, secret_key = ask_user_for_secrets(source=source)
-    if half_life is None:
-        half_life = ask_user_for_half_life(access_key)
-    if isinstance(half_life, basestring) and not half_life.isdigit():
-        if half_life == "hour":
-            half_life = 60 * 60
-        elif half_life == "day":
-            half_life = 60 * 60 * 24
-        elif half_life == "week":
-            half_life = 60 * 60 * 24 * 7
-        else:
-            raise CredoError("Unknown half life value", half_life=half_life)
+    half_life = normalise_half_life(half_life, access_key) or getattr(credo, "half_life", None)
     iam_pair = IamPair(access_key, secret_key, half_life=half_life)
 
     # Make sure the iam pair is for the right place
